==> fwbuilder_3.0.7.orig.tar.gz: fwbuilder-3.0.7/src/gui/FirewallInstallerCisco.h <==
/* 

                          Firewall Builder

                 Copyright (C) 2008 NetCitadel, LLC

  Author:  Vadim Kurland     vadim@fwbuilder.org

  $Id: FirewallInstallerCisco.h 585 2008-10-09 05:08:41Z vadim $

  This program is free software which we release under the GNU General Public
  License. You may redistribute and/or modify this program under the terms
  of that license as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  To get a copy of the GNU General Public License, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/


#ifndef __FIREWALLINSTALLERCISCO_H_
#define __FIREWALLINSTALLERCISCO_H_


#include "../../config.h"

#include "FirewallInstaller.h"

#include <qstring.h>
#include <qstringlist.h>
#include <qprocess.h>
#include <qobject.h>

namespace libfwbuilder
{
    class Firewall;
}

class FirewallInstallerCisco : public FirewallInstaller
{
    Q_OBJECT

public:

    FirewallInstallerCisco(instDialog *_dlg, instConf *_cnf, const QString &_p):
        FirewallInstaller(_dlg, _cnf, _p) {}

    virtual bool packInstallJobsList(libfwbuilder::Firewall*);
    virtual void activatePolicy();
    
};


#endif

==> fwbuilder-4.0.2.tar.gz: fwbuilder-4.0.2/src/gui/FirewallInstallerCisco.h <==
/* 

                          Firewall Builder

                 Copyright (C) 2008 NetCitadel, LLC

  Author:  Vadim Kurland     vadim@fwbuilder.org

  $Id: FirewallInstallerCisco.h 2249 2009-12-23 01:02:51Z vadim $

  This program is free software which we release under the GNU General Public
  License. You may redistribute and/or modify this program under the terms
  of that license as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  To get a copy of the GNU General Public License, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/


#ifndef __FIREWALLINSTALLERCISCO_H_
#define __FIREWALLINSTALLERCISCO_H_


#include "../../config.h"

#include "FirewallInstaller.h"

#include <qstring.h>
#include <qstringlist.h>
#include <qprocess.h>
#include <qobject.h>
#include <QStringList>

namespace libfwbuilder
{
    class Firewall;
}

class FirewallInstallerCisco : public FirewallInstaller
{
    Q_OBJECT;

    QStringList config_lines;

    virtual QString getDestinationDir(const QString &dir);
    
    virtual bool readManifest(const QString &conffie,
                              QMap<QString, QString> *all_files);
public:

    FirewallInstallerCisco(instDialog *_dlg, instConf *_cnf, const QString &_p);

    virtual bool packInstallJobsList(libfwbuilder::Firewall*);
    virtual void activatePolicy(const QString &script, const QString &args);
    
};


#endif
